@@ -84,15 +84,13 @@
 #'
 #' # 3. RData files are read in by `base::load()` but cannot be assigned to an
 #' # object name. The following shows two possible ways to read in such files.
+#' # First, the RData object can be loaded to the environment without object assignment.
 #'
-#' # First, without relying on `get_dataframe_*`, write as a binary file:
-#' as_binary <- get_file_by_doi(
-#'  filedoi = "doi:10.70122/FK2/PPIAXE/5VPXKE",
-#'  server = "demo.dataverse.org")
-#'
-#' temp <- tempdir()
-#' writeBin(as_binary, path(temp, "county.RData"))
-#' load(path(temp, "county.RData"))
+#' get_dataframe_by_doi(
+#'   filedoi = "10.70122/FK2/PPIAXE/X2FC5V",
+#'   server = "demo.dataverse.org",
+#'   original = TRUE,
+#'   .f = function(x) load(x, envir = .GlobalEnv))
 #'
 #' # If you are certain each RData contains only one object, one could define a
 #' # custom function used in https://stackoverflow.com/a/34926943
@@ -151,7 +149,7 @@ get_dataframe_by_id <- function(
   }
 
   # READ raw data
-  raw <- get_file(file = fileid, original = original, ...)
+  raw <- get_file(file = fileid, original = original, return_url = FALSE, ...)
 
   # save to temp and then read it in with supplied function
   if (!is.null(.f)) {
